@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.64';
+$Test::BDD::Cucumber::Executor::VERSION = '0.66';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.64
+version 0.66
 
 =head1 DESCRIPTION
 
@@ -166,11 +166,6 @@ sub execute {
     # Get all scenarios
     my @scenarios = @{ $feature->scenarios() };
 
-    # Filter them by the tag spec, if we have one
-    if ( defined $tag_spec ) {
-        @scenarios = $tag_spec->filter(@scenarios);
-    }
-
     $_->pre_feature( $feature, $feature_stash ) for @{ $self->extensions };
     for my $outline (@scenarios) {
 
@@ -181,7 +176,8 @@ sub execute {
                 scenario      => $outline,
                 feature       => $feature,
                 feature_stash => $feature_stash,
-                harness       => $harness
+                harness       => $harness,
+                tagspec       => $tag_spec,
             }
         );
     }
@@ -215,29 +211,53 @@ representing the Background
 
 sub execute_outline {
     my ( $self, $options ) = @_;
-    my ( $feature, $feature_stash, $harness, $outline, $background )
-      = @$options{qw/ feature feature_stash harness scenario background /};
+    my ( $feature, $feature_stash, $harness, $outline, $background, $tagspec )
+      = @$options{qw/ feature feature_stash harness scenario background tagspec /};
 
     # Multiply out Scenario Outlines as appropriate
-    my @datasets = @{ $outline->data };
-    @datasets = ( {} ) unless @datasets;
+    my @datasets = @{ $outline->datasets };
+    if (not @datasets) {
+        if (not $tagspec or $tagspec->filter($outline) ) {
+            $self->execute_scenario(
+                {
+                    feature => $feature,
+                    feature_stash => $feature_stash,
+                    harness => $harness,
+                    scenario => $outline,
+                    background => $background,
+                    scenario_stash => {},
+                    outline_state => {},
+                    dataset => {},
+                });
+        }
 
-    my $outline_state = {};
+        return;
+    }
 
-    foreach my $dataset (@datasets) {
-        $self->execute_scenario(
-            {
-                feature => $feature,
-                feature_stash => $feature_stash,
-                harness => $harness,
-                scenario => $outline,
-                background => $background,
-                scenario_stash => {},
-                outline_state => $outline_state,
-                dataset => $dataset,
-            });
+    if ($tagspec) {
+        @datasets = $tagspec->filter(@datasets);
+        return unless @datasets;
+    }
 
-        $outline_state->{'short_circuit'} ||= $self->_bail_out;
+
+    foreach my $rows (@datasets) {
+        my $outline_state = {};
+
+        foreach my $row (@{$rows->data}) {
+            $self->execute_scenario(
+                {
+                    feature => $feature,
+                    feature_stash => $feature_stash,
+                    harness => $harness,
+                    scenario => $outline,
+                    background => $background,
+                    scenario_stash => {},
+                    outline_state => $outline_state,
+                    dataset => $row,
+                });
+
+            $outline_state->{'short_circuit'} ||= $self->_bail_out;
+        }
     }
 }
 
